"""Module for useful functions."""

import itertools


def consume(iterative, n):
    """Consume n elements from iterative object.

    Args:
        iterative (iter): Python iterative object.
        n (int): Number of elements to consume.

    """
    next(itertools.islice(iterative, n - 1, n), None)


def subdict(dictionary, keys, all_must_be_present=True):
    """Return a subdictionary of dictionary containing only keys.

    Args:
        dictionary (dict): Dictionary to take a subdictionary from.
        keys (list): List of keys to take from dictionary.
        all_must_be_present (bool): If True, all keys must be present in
            dictionary. If False, only keys that are present are returned.

    Returns:
        dict: Subdictionary of dictionary containing only keys.

    """
    if all_must_be_present:
        return {key: dictionary[key] for key in keys}
    else:
        return {key: dictionary[key] for key in keys if key in dictionary}


def get_sublcasses(cls):
    """Returns all classes that inherits from the provided class.

    Returns all classes that inherits from cls, both directly and
    indirectly

    Returns:
        List[Type[object]]: List of classes that inherits from the
            provided class

    """
    subclasses = []
    for subclass in cls.__subclasses__():
        subclasses.append(subclass)
        subclasses.extend(get_sublcasses(subclass))
    return subclasses
